# Welcome
This is the current release of baangt - the tool for "Basic And Advanced Next Generation Testing".

## Installation in a virtual environment:
``pip-env``
and
``pip install baangt``

Please see latest news on http://baangt.org and for commercial customers http://baangt.com